EventResult

Type Alias EventResult 

pub type EventResult = Result<MaybeWindowAvailable, PlatformError>;
A type alias for the result of an event. Err means that the event could not be processed, and Ok contains the event.

Aliased Type

pub enum EventResult {
    Ok(MaybeWindowAvailable),
    Err(WindowsError),
}

Variants

1.0.0

Ok(MaybeWindowAvailable)

Contains the success value

1.0.0

Err(WindowsError)

Contains the error value