pub type EventRx = UnboundedReceiver<EventResult>;Expand description
A type alias for the window event reception channel.
Aliased Type
pub struct EventRx { /* private fields */ }pub type EventRx = UnboundedReceiver<EventResult>;A type alias for the window event reception channel.
pub struct EventRx { /* private fields */ }