pub type EventTx = UnboundedSender<EventResult>;Expand description
A type alias for the window event transmission channel.
Aliased Type
pub struct EventTx { /* private fields */ }pub type EventTx = UnboundedSender<EventResult>;A type alias for the window event transmission channel.
pub struct EventTx { /* private fields */ }