pub type EventResult = Result<MaybeWindowAvailable, PlatformError>;Expand description
A type alias for the result of an event.
Err means that the event could not be processed, and Ok contains the event.
Aliased Type
pub enum EventResult {
Ok(MaybeWindowAvailable),
Err(WindowsError),
}Variants
Ok(MaybeWindowAvailable)
Contains the success value
Err(WindowsError)
Contains the error value